@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hakyll
 version: 4.7.5.1
-id: hakyll-4.7.5.1-974b209adf11364a92e094b70144f0c3
-key: hakyl_CTR0czlXL4807bCjQymRYf
+id: hakyll-4.7.5.1-3724481241875863af6c18eb2d026c93
+key: hakyl_Dzfl0Z5Hfhk1uSjpOmqzaQ
 license: BSD3
 maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
 homepage: http://jaspervdj.be/hakyll
@@ -50,35 +50,35 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.1
-hs-libraries: HShakyll-4.7.5.1-CTR0czlXL4807bCjQymRYf
+hs-libraries: HShakyll-4.7.5.1-Dzfl0Z5Hfhk1uSjpOmqzaQ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
-    blaze-html-0.8.1.1-b598557be4ce3598e270c7592be1f33c
-    blaze-markup-0.7.0.3-adfaa12a6c8f95338d1eda4a379eb541
+    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
+    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    cmdargs-0.10.13-bef2ab6ecde2bd42e13eb0f01d9aba51
+    cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
+    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.8-b225c20ac1fcbbf432d8f808f3157496
-    http-types-0.9-26f1bedc2b9255e48a8e673fef6095b1
-    lrucache-1.2.0.0-3a28e4fefc3e5f1a602d3f3824abd887
+    http-conduit-2.1.8-7af4c72b658e9ba872144aa8bca2c27b
+    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
+    lrucache-1.2.0.0-97fd799690b7e95999ded6be87e87c88
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    network-uri-2.6.0.3-f06058f927fb674b53980227bb9fbb26
-    pandoc-1.16.0.2-b6ca3d2a83b82cc8a850f7a80352d67f
-    pandoc-citeproc-0.9-c2a814a20fc2d15a9da3080d7e210ae5
-    parsec-3.1.9-76531bee8e01e972cbf1b63ff50c8cf1
+    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
+    pandoc-1.16.0.2-b6635e89c036b6c1a009fe0e8c58734b
+    pandoc-citeproc-0.9-39d757811f1dcaf68e3c2fc4fa9a7619
+    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
-    regex-tdfa-1.2.1-16741c74b5e819c14644b05dfa6300c4
-    tagsoup-0.13.8-ddedc05ba7848a219e8c0cd63e84ff07
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    regex-tdfa-1.2.1-2f2ff40a952b63109ef37be1ffea97d0
+    tagsoup-0.13.8-ae67a6a9bc7b71798dd8f975b70085f0
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
 haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
